from setuptools import setup

setup(name='package_a8b11', 
      version='0.1', 
      description='The funniest joke in the world', 
      author='David Ivan', 
      author_email='avandavad@gmail.com', 
      license='MIT', 
      packages=['package_a8b11'], 
      zip_safe=False)
